@@ -2,6 +2,7 @@
  * vout_sdl.c: SDL video output display method
  *****************************************************************************
  * Copyright (C) 1998, 1999, 2000 VideoLAN
+ * $Id: vout_sdl.c,v 1.46 2001/04/06 09:15:47 sam Exp $
  *
  * Authors: Samuel Hocevar <sam@zoy.org>
  *          Pierre Baillet <oct@zoy.org>
@@ -74,13 +75,20 @@ typedef struct vout_sys_s
 {
     int i_width;
     int i_height;
+
     SDL_Surface *   p_display;                             /* display device */
     SDL_Overlay *   p_overlay;                             /* overlay device */
+
     boolean_t   b_fullscreen;
     boolean_t   b_overlay;
     boolean_t   b_cursor;
     boolean_t   b_reopen_display;
+
+    boolean_t   b_cursor_autohidden;
+    mtime_t     i_lastmoved;
+
     Uint8   *   p_sdl_buf[2];                          /* Buffer information */
+
 } vout_sys_t;
 
 /*****************************************************************************
@@ -158,6 +166,10 @@ static int vout_Create( vout_thread_t *p_vout )
     }
 
     p_vout->p_sys->b_cursor = 1; /* TODO should be done with a main_GetInt.. */
+
+    p_vout->p_sys->b_cursor_autohidden = 0;
+    p_vout->p_sys->i_lastmoved = mdate();
+
     p_vout->p_sys->b_fullscreen = main_GetIntVariable( VOUT_FULLSCREEN_VAR,
                                 VOUT_FULLSCREEN_DEFAULT );
     p_vout->p_sys->b_overlay = main_GetIntVariable( VOUT_OVERLAY_VAR,
@@ -201,7 +213,8 @@ static int vout_Create( vout_thread_t *p_vout )
     intf_AssignKey(p_intf, SDLK_c,      INTF_KEY_TOGGLE_GRAYSCALE, 0);
     intf_AssignKey(p_intf, SDLK_SPACE,  INTF_KEY_TOGGLE_INTERFACE, 0);
     intf_AssignKey(p_intf, SDLK_i,      INTF_KEY_TOGGLE_INFO, 0);
-    intf_AssignKey(p_intf, SDLK_s,      INTF_KEY_TOGGLE_SCALING, 0); }
+    intf_AssignKey(p_intf, SDLK_s,      INTF_KEY_TOGGLE_SCALING, 0);
+    intf_AssignKey(p_intf, SDLK_d,      INTF_KEY_DUMP_STREAM, 0); }
 
     return( 0 );
 }
@@ -216,8 +229,10 @@ static int vout_Init( vout_thread_t *p_vout )
     /* This hack is hugly, but hey, you are, too. */
 
     SDL_Overlay *   p_overlay;
-
-    p_overlay = SDL_CreateYUVOverlay( VOUT_WIDTH_DEFAULT, VOUT_HEIGHT_DEFAULT,
+    
+    p_overlay = SDL_CreateYUVOverlay( 
+           main_GetIntVariable( VOUT_WIDTH_VAR,VOUT_WIDTH_DEFAULT ),
+           main_GetIntVariable( VOUT_HEIGHT_VAR,VOUT_HEIGHT_DEFAULT ),
                                       SDL_YV12_OVERLAY, 
                                       p_vout->p_sys->p_display );
     intf_Msg( "vout: YUV acceleration %s",
@@ -259,7 +274,7 @@ static void vout_Destroy( vout_thread_t *p_vout )
 static int vout_Manage( vout_thread_t *p_vout )
 {
     SDL_Event event;                                            /* SDL event */
-    Uint8   i_key;
+    Uint8     i_key;
 
     /* Process events */
     while( SDL_PollEvent(&event) )
@@ -272,6 +287,22 @@ static int vout_Manage( vout_thread_t *p_vout )
             p_vout->i_changes |= VOUT_SIZE_CHANGE;
             break;
 
+        case SDL_MOUSEMOTION:
+            if( p_vout->p_sys->b_cursor &&
+                (abs(event.motion.xrel) > 2 || abs(event.motion.yrel) > 2) )
+            {
+                if( p_vout->p_sys->b_cursor_autohidden )
+                {
+                    p_vout->p_sys->b_cursor_autohidden = 0;
+                    SDL_ShowCursor( 1 );
+                }
+                else
+                {
+                    p_vout->p_sys->i_lastmoved = mdate();
+                }
+            }
+            break;
+
         case SDL_MOUSEBUTTONUP:
             switch( event.button.button )
             {
@@ -382,39 +413,33 @@ static int vout_Manage( vout_thread_t *p_vout )
     {
         p_vout->p_sys->b_fullscreen = ! p_vout->p_sys->b_fullscreen;
 
-        if( p_vout->p_sys->b_fullscreen )
-        {
-            p_vout->p_sys->b_fullscreen = 0;
-            p_vout->p_sys->b_cursor = 1;
-            SDL_ShowCursor( 1 );
-        }
-        else
-        {
-            p_vout->p_sys->b_fullscreen = 1;
-            p_vout->p_sys->b_cursor = 0;
-            SDL_ShowCursor( 0 );
-        }
-
         SDL_WM_ToggleFullScreen(p_vout->p_sys->p_display);
 
+        p_vout->p_sys->b_cursor_autohidden = 0;
+        SDL_ShowCursor( p_vout->p_sys->b_cursor &&
+                        ! p_vout->p_sys->b_cursor_autohidden );
+
         p_vout->i_changes &= ~VOUT_FULLSCREEN_CHANGE;
     }
 
     /*
      * Pointer change
      */
+    if( ! p_vout->p_sys->b_cursor_autohidden &&
+        ( mdate() - p_vout->p_sys->i_lastmoved > 2000000 ) )
+    {
+        /* Hide the mouse automatically */
+        p_vout->p_sys->b_cursor_autohidden = 1;
+        SDL_ShowCursor( 0 );
+    }
+
     if( p_vout->i_changes & VOUT_CURSOR_CHANGE )
     {
-        if( p_vout->p_sys->b_cursor )
-        {
-            SDL_ShowCursor( 0 );
-            p_vout->p_sys->b_cursor = 0;
-        }
-        else
-        {
-            SDL_ShowCursor( 1 );
-            p_vout->p_sys->b_cursor = 1;
-        }
+        p_vout->p_sys->b_cursor = ! p_vout->p_sys->b_cursor;
+
+        SDL_ShowCursor( p_vout->p_sys->b_cursor &&
+                        ! p_vout->p_sys->b_cursor_autohidden );
+
         p_vout->i_changes &= ~VOUT_CURSOR_CHANGE;
     }
     
@@ -469,7 +494,6 @@ static void vout_Display( vout_thread_t *p_vout )
         }
         else
         {
-        
             /*
              * p_vout->p_rendered_pic->p_y/u/v contains the YUV buffers to
              * render 
@@ -539,20 +563,28 @@ static int SDLOpenDisplay( vout_thread_t *p_vout )
     flags = SDL_ANYFORMAT | SDL_HWPALETTE;
 
     if( p_vout->p_sys->b_fullscreen )
+    {
         flags |= SDL_FULLSCREEN;
+    }
     else
+    {
         flags |= SDL_RESIZABLE;
+    }
 
     if( p_vout->b_need_render )
+    {
         flags |= SDL_HWSURFACE | SDL_DOUBLEBUF;
+    }
     else
+    {
         flags |= SDL_SWSURFACE; /* save video memory */
+    }
 
     bpp = SDL_VideoModeOK( p_vout->p_sys->i_width,
                            p_vout->p_sys->i_height,
                            p_vout->i_screen_depth, flags );
 
-    if(bpp == 0)
+    if( bpp == 0 )
     {
         intf_ErrMsg( "vout error: no video mode available" );
         return( 1 );
@@ -568,12 +600,7 @@ static int SDLOpenDisplay( vout_thread_t *p_vout )
         return( 1 );
     }
 
-    SDL_LockSurface(p_vout->p_sys->p_display);
-
-    if( p_vout->p_sys->b_fullscreen )
-        SDL_ShowCursor( 0 );
-    else
-        SDL_ShowCursor( 1 );
+    SDL_LockSurface( p_vout->p_sys->p_display );
 
     SDL_WM_SetCaption( VOUT_TITLE " (SDL output)",
                        VOUT_TITLE " (SDL output)" );
